@@ -4,10 +4,10 @@ import unittest
 class TestPluginCubeTV(unittest.TestCase):
     def test_can_handle_url(self):
         # should match
-        self.assertTrue(CubeTV.can_handle_url("https://www.cubetv.sg/Tecnosh"))
-        self.assertTrue(CubeTV.can_handle_url("https://www.cubetv.sg/letsgodroid"))
-        self.assertTrue(CubeTV.can_handle_url("https://www.cubetv.sg/14939646"))
-        self.assertTrue(CubeTV.can_handle_url("https://www.cubetv.sg/Luladopub"))
+        self.assertTrue(CubeTV.can_handle_url("https://www.cube.tv/Tecnosh"))
+        self.assertTrue(CubeTV.can_handle_url("https://www.cube.tv/garotadoblog"))
+        self.assertTrue(CubeTV.can_handle_url("https://www.cube.tv/demi"))
+        self.assertTrue(CubeTV.can_handle_url("https://www.cube.tv/Luladopub"))
         # shouldn't match
         self.assertFalse(CubeTV.can_handle_url("https://www.cubetv.sg/g/PUBG"))
         self.assertFalse(CubeTV.can_handle_url("https://www.cubetv.sg/c"))
